## $Id: interfaces.py 9318 2012-10-08 13:28:17Z henrik $
##
## Copyright (C) 2011 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##

import zope.i18nmessageid
from zope import schema
from zc.sourcefactory.basic import BasicSourceFactory
from waeup.kofa.interfaces import (SimpleKofaVocabulary,
    ISessionConfiguration, academic_sessions_vocab)

_ = MessageFactory = zope.i18nmessageid.MessageFactory('waeup.futminna')

# It's recommended to replicate all fields from the base package here.
class ICustomSessionConfiguration(ISessionConfiguration):
    """A session configuration object.
    """

    # Base fees, do not remove.

    school_fee_base = schema.Float(
        title = _(u'School Fee (ignored)'),
        default = 0.0,
        required = False,
        )

    application_fee = schema.Float(
        title = _(u'Application Fee (fallback)'),
        default = 0.0,
        required = False,
        )

    clearance_fee = schema.Float(
        title = _(u'Clearance Fee (ignored)'),
        default = 0.0,
        required = False,
        )

    booking_fee = schema.Float(
        title = _(u'Booking Fee'),
        default = 0.0,
        required = False,
        )

    # Additional fees in custom package

    maint_fee = schema.Float(
        title = _(u'Maintenance Fee (ignored)'),
        default = 0.0,
        required = False,
        )

    gown_fee = schema.Float(
        title = _(u'Gown Fee'),
        default = 0.0,
        required = False,
        )

    transfer_fee = schema.Float(
        title = _(u'Transfer Fee'),
        default = 0.0,
        required = False,
        )

    penalty_ug = schema.Float(
        title = _(u'UG Penalty Fee'),
        default = 0.0,
        required = False,
        )

    penalty_pg = schema.Float(
        title = _(u'PG Penalty Fee'),
        default = 0.0,
        required = False,
        )

    def getSessionString():
        """Returns the session string from the vocabulary.
        """


class ICustomSessionConfigurationAdd(ICustomSessionConfiguration):
    """A session configuration object in add mode.
    """

    academic_session = schema.Choice(
        title = _(u'Academic Session'),
        source = academic_sessions_vocab,
        default = None,
        required = True,
        readonly = False,
        )

ICustomSessionConfigurationAdd[
    'academic_session'].order =  ICustomSessionConfiguration[
    'academic_session'].order